@@ -25,7 +25,7 @@ class ContentType(Enum):
 
 class ContentObject:
 
-    def __init__(self, name, id=new_id(), contentType=ContentType.DOCUMENT, tags=[], metadata={}):
+    def __init__(self, name="untitled", id=new_id(), contentType=ContentType.DOCUMENT, tags=[], metadata={}):
         self.id = id
         self.name = name
         self.contentType = contentType
@@ -294,10 +294,11 @@ class Pipeline:
                 try:
                     self.sink.sink(document)
                 except:
-                    document.exceptions.append({
-                        "step": self.sink.get_name(),
-                        "exception": sys.exc_info()[0]
-                    })
+                    if document:
+                        document.exceptions.append({
+                            "step": self.sink.get_name(),
+                            "exception": sys.exc_info()[0]
+                        })
                     if self.stop_on_exception:
                         raise
 
